==> ktp-text-ui-0.5.80.tar.bz2: ktp-text-ui-0.5.80/filters/emoticons/ktptextui_message_filter_emoticons.desktop.cmake <==
[Desktop Entry]
Name=Emoticons
Name[bs]=Emotikoni
Name[ca]=Emoticones
Name[ca@valencia]=Emoticones
Name[cs]=Emotikony
Name[da]=Emotikoner
Name[de]=Emoticons
Name[el]=Emoticons
Name[es]=Emoticonos
Name[et]=Emotikonid
Name[fi]=Hymiöt
Name[fr]=Émoticônes
Name[ga]=Straoiseoga
Name[gl]=Emoticonas
Name[hu]=Hangulatjelek
Name[ia]=Emoticones
Name[it]=Emoticon
Name[kk]=Көңіл күйі белгілері
Name[lt]=Jaustukai
Name[nb]=Humørfjes
Name[nl]=Emoticons
Name[nn]=Fjesingar
Name[pl]=Emotikony
Name[pt]=Ícones Emotivos
Name[pt_BR]=Emoticons
Name[ro]=Emoticoni
Name[ru]=Смайлики
Name[se]=Mojánat
Name[sk]=Emotikony
Name[sl]=Izrazne ikone
Name[sr]=Емотикони
Name[sr@ijekavian]=Емотикони
Name[sr@ijekavianlatin]=Emotikoni
Name[sr@latin]=Emotikoni
Name[sv]=Smilisar
Name[tr]=İfadeler
Name[uk]=Емоційки
Name[wa]=Xhinêyes
Name[x-test]=xxEmoticonsxx
Name[zh_CN]=表情
Name[zh_TW]=表情圖示
Encoding=UTF-8
Comment=Show emoticons (smiley faces) inside the chat
Comment[bs]=Prikaži emotikone (izraze osjećanja znakovima) u ćaskanju
Comment[ca]=Mostra les emoticones (cares somrients) dins del xat
Comment[ca@valencia]=Mostra les emoticones (cares somrients) dins del xat
Comment[cs]=Zobrazit emotikony (smějící se obličeje) v rozhovoru
Comment[da]=Vis emotikoner (smileys) indeni chatten
Comment[de]=Emoticons im Chat anzeigen
Comment[el]=Να εμφανίζονται τα emoticons (γελαστά πρόσωπα) μέσα στη συνομιλία
Comment[es]=Mostrar emoticonos (caras sonrientes) dentro del chat
Comment[et]=Emotikonide (naerunägude) näitamine vestluses
Comment[fi]=Näytä hymiöt (hymynaamat) keskustelussa
Comment[fr]=Afficher les émoticônes (visages souriants) au sein de la discussion
Comment[gl]=Mostrar as emoticonas (as cariñas sorrintes) na conversa
Comment[hu]=Hangulatjelek (smiley arcok) megjelenítése a csevegésen belül
Comment[ia]=Monstra emoticones (facias surridente) intra le conversation
Comment[it]=Mostra emoticon (faccine) nella chat
Comment[kk]=Көңіл күйі белгілерді чатта көрсету
Comment[nb]=Vis humørfjes (emotikoner) inne i praten
Comment[nl]=Emoticons tonen (lachende gezichtjes) in de chat
Comment[pl]=Pokaż emotikony (buźki) wewnątrz okna rozmowy
Comment[pt]=Mostrar os ícones emotivos nas conversas
Comment[pt_BR]=Mostra emoticons (carinhas) no interior do bate-papo
Comment[ro]=Arată emoticoni (fețe zîmbitoare) în interiorul discuției
Comment[ru]=Показывать смайлики в чате
Comment[sk]=Zobraziť emotikony (smajlíkov) v rozhovore
Comment[sl]=Pokaži izrazne ikone (obraze smeškov) znotraj klepeta
Comment[sr]=Приказ емотикона (смешкова) унутар ћаскања
Comment[sr@ijekavian]=Приказ емотикона (смешкова) унутар ћаскања
Comment[sr@ijekavianlatin]=Prikaz emotikona (smeškova) unutar ćaskanja
Comment[sr@latin]=Prikaz emotikona (smeškova) unutar ćaskanja
Comment[sv]=Visa smilisar inne i chatten
Comment[tr]=Sohbet içerisinde ifadeleri (gülen suratları) göster
Comment[uk]=Показувати емоційки (смайлики) у вікні спілкування
Comment[wa]=Mostrer les xhinêyes (riyants vizaedjes) å dvins do berdelaedje
Comment[x-test]=xxShow emoticons (smiley faces) inside the chatxx
Comment[zh_CN]=聊天中显示表情 (笑脸)
Comment[zh_TW]=在聊天內顯示表情圖示
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_emoticons
X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
X-KDE-PluginInfo-Name=emoticons
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

==> ktp-text-ui-0.6.2.1.tar.bz2: ktp-text-ui-0.6.2.1/filters/emoticons/ktptextui_message_filter_emoticons.desktop.cmake <==
[Desktop Entry]
Name=Emoticons
Name[bs]=Emotikoni
Name[ca]=Emoticones
Name[ca@valencia]=Emoticones
Name[cs]=Emotikony
Name[da]=Emotikoner
Name[de]=Emoticons
Name[el]=Emoticons
Name[es]=Emoticonos
Name[et]=Emotikonid
Name[fi]=Hymiöt
Name[fr]=Émoticônes
Name[ga]=Straoiseoga
Name[gl]=Emoticonas
Name[hu]=Hangulatjelek
Name[ia]=Emoticones
Name[it]=Emoticon
Name[kk]=Көңіл күйі белгілері
Name[lt]=Jaustukai
Name[mr]=भावप्रतिमा
Name[nb]=Humørfjes
Name[nl]=Emoticons
Name[nn]=Fjesingar
Name[pl]=Emotikony
Name[pt]=Ícones Emotivos
Name[pt_BR]=Emoticons
Name[ro]=Emoticoni
Name[ru]=Смайлики
Name[se]=Mojánat
Name[sk]=Emotikony
Name[sl]=Izrazne ikone
Name[sr]=Емотикони
Name[sr@ijekavian]=Емотикони
Name[sr@ijekavianlatin]=Emotikoni
Name[sr@latin]=Emotikoni
Name[sv]=Smilisar
Name[tr]=İfadeler
Name[uk]=Емоційки
Name[wa]=Xhinêyes
Name[x-test]=xxEmoticonsxx
Name[zh_CN]=表情
Name[zh_TW]=表情圖示
Encoding=UTF-8
Comment=Show emoticons (smiley faces) inside the chat
Comment[bs]=Prikaži emotikone (izraze osjećanja znakovima) u ćaskanju
Comment[ca]=Mostra les emoticones (cares somrients) dins del xat
Comment[ca@valencia]=Mostra les emoticones (cares somrients) dins del xat
Comment[cs]=Zobrazit emotikony (smějící se obličeje) v rozhovoru
Comment[da]=Vis emotikoner (smileys) indeni chatten
Comment[de]=Emoticons im Chat anzeigen
Comment[el]=Να εμφανίζονται τα emoticons (γελαστά πρόσωπα) μέσα στη συνομιλία
Comment[es]=Mostrar emoticonos (caras sonrientes) dentro del chat
Comment[et]=Emotikonide (naerunägude) näitamine vestluses
Comment[fi]=Näytä hymiöt (hymynaamat) keskustelussa
Comment[fr]=Afficher les émoticônes (visages souriants) au sein de la discussion
Comment[gl]=Mostrar as emoticonas (as cariñas sorrintes) na conversa
Comment[hu]=Hangulatjelek (smiley arcok) megjelenítése a csevegésen belül
Comment[ia]=Monstra emoticones (facias surridente) intra le conversation
Comment[it]=Mostra emoticon (faccine) nella chat
Comment[kk]=Көңіл күйі белгілерді чатта көрсету
Comment[lt]=Rodyti šypsenėles pokalbio viduje
Comment[nb]=Vis humørfjes (emotikoner) inne i praten
Comment[nl]=Emoticons tonen (lachende gezichtjes) in de chat
Comment[pl]=Pokaż emotikony (buźki) wewnątrz okna rozmowy
Comment[pt]=Mostrar os ícones emotivos nas conversas
Comment[pt_BR]=Mostra emoticons (carinhas) no interior do bate-papo
Comment[ro]=Arată emoticoni (fețe zîmbitoare) în interiorul discuției
Comment[ru]=Показывать смайлики в чате
Comment[sk]=Zobraziť emotikony (smajlíkov) v rozhovore
Comment[sl]=Pokaži izrazne ikone (obraze smeškov) znotraj klepeta
Comment[sr]=Приказ емотикона (смешкова) унутар ћаскања
Comment[sr@ijekavian]=Приказ емотикона (смјешкова) унутар ћаскања
Comment[sr@ijekavianlatin]=Prikaz emotikona (smješkova) unutar ćaskanja
Comment[sr@latin]=Prikaz emotikona (smeškova) unutar ćaskanja
Comment[sv]=Visa smilisar inne i chatten
Comment[tr]=Sohbet içerisinde ifadeleri (gülen suratları) göster
Comment[uk]=Показувати емоційки (смайлики) у вікні спілкування
Comment[wa]=Mostrer les xhinêyes (riyants vizaedjes) å dvins do berdelaedje
Comment[x-test]=xxShow emoticons (smiley faces) inside the chatxx
Comment[zh_CN]=聊天中显示表情 (笑脸)
Comment[zh_TW]=在聊天內顯示表情圖示
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_emoticons
X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
X-KDE-PluginInfo-Name=emoticons
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@
